@@ -5,7 +5,7 @@ package Bundle::SYP;
 use strict;
 use utf8;
 use warnings 'all';
-our $VERSION = '0.6'; # VERSION
+our $VERSION = '0.7'; # VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Bundle::SYP - SYP's cozy environment
 
 =head1 VERSION
 
-version 0.6
+version 0.7
 
 =head1 SYNOPSIS
 
@@ -54,6 +54,8 @@ Bash::Completion::Plugins::perlbrew
 
 Config::General
 
+DBD::SQLite
+
 DB_File
 
 Daemon::Generic
@@ -120,6 +122,8 @@ Memoize
 
 Mojolicious
 
+MongoDB
+
 Moose
 
 MooseX::NonMoose
@@ -156,6 +160,8 @@ Text::CSV
 
 Text::CSV_XS
 
+Text::TabularDisplay
+
 Text::Unidecode
 
 Tie::Handle::CSV
